

<img align="left" src="https://desycloud.desy.de/index.php/s/25EwEzgpyFMd2bC/preview" width="150" height="150"/>  
<br>

# LSST plugin for AMPEL

<br><br>
LSST-specific implementations for Ampel such as:

- An _AlertSupplier_ compatible with plasticc generated alerts
- Shaper classes for ingestion
